@@ -1,7 +1,6 @@
-#ifndef eulerr_constants_h_
-#define eulerr_constants_h_
+#pragma once
+
+#include <RcppArmadillo.h>
 
 const auto SMALL = std::pow(std::numeric_limits<double>::epsilon(), 0.95);
 const auto INF   = std::numeric_limits<double>::infinity();
-
-#endif // eulerr_constants_h_
